@@ -18,8 +18,11 @@ from collections import namedtuple
 from typing import TypeVar
 
 from gs_quant.backtests.backtest_utils import *
+from gs_quant.backtests.backtest_objects import ConstantTransactionModel, TransactionModel
+from gs_quant.risk.transform import Transformer
 from gs_quant.base import Priceable
 from gs_quant.markets.securities import *
+from gs_quant.markets.portfolio import Portfolio
 from gs_quant.target.backtests import BacktestTradingQuantityType
 
 action_count = 1
@@ -36,6 +39,7 @@ class Action(object):
             action_count += 1
         else:
             self._name = name
+        self._transaction_cost = ConstantTransactionModel(0)
 
     @property
     def calc_type(self):
@@ -45,6 +49,10 @@ class Action(object):
     def risk(self):
         return self._risk
 
+    @property
+    def transaction_cost(self):
+        return self._transaction_cost
+
 
 TAction = TypeVar('TAction', bound='Action')
 
@@ -53,7 +61,8 @@ class AddTradeAction(Action):
     def __init__(self,
                  priceables: Union[Priceable, Iterable[Priceable]],
                  trade_duration: Union[str, dt.date, dt.timedelta] = None,
-                 name: str = None):
+                 name: str = None,
+                 transaction_cost: TransactionModel = ConstantTransactionModel(0)):
         """
         create an action which adds a trade when triggered.  The trades are resolved on the trigger date (state) and
         last until the trade_duration if specified or for all future dates if not.
@@ -62,16 +71,19 @@ class AddTradeAction(Action):
                                if left as None the
                                trade will be added for all future dates
         :param name: optional additional name to the priceable name
+        :param transaction_cost: optional a cash amount paid for each transaction, paid on both enter and exit
         """
         super().__init__(name)
-        self._priceables = make_list(priceables)
+
+        self._priceables = []
         self._dated_priceables = {}
         self._trade_duration = trade_duration
-        for i, p in enumerate(self._priceables):
+        self._transaction_cost = transaction_cost
+        for i, p in enumerate(make_list(priceables)):
             if p.name is None:
-                p.name = '{}_Priceable{}'.format(self._name, i)
+                self._priceables.append(p.clone(name=f'{self._name}_Priceable{i}'))
             else:
-                p.name = '{}_{}'.format(self._name, p.name)
+                self._priceables.append(p.clone(name=f'{self._name}_{p.name}'))
 
     @property
     def priceables(self):
@@ -88,11 +100,16 @@ class AddTradeAction(Action):
     def dated_priceables(self):
         return self._dated_priceables
 
+    @property
+    def transaction_cost(self):
+        return self._transaction_cost
+
 
 AddTradeActionInfo = namedtuple('AddTradeActionInfo', 'scaling')
 EnterPositionQuantityScaledActionInfo = namedtuple('EnterPositionQuantityScaledActionInfo', 'not_applicable')
 HedgeActionInfo = namedtuple('HedgeActionInfo', 'not_applicable')
 ExitTradeActionInfo = namedtuple('ExitTradeActionInfo', 'not_applicable')
+RebalanceActionInfo = namedtuple('RebalanceActionInfo', 'not_applicable')
 
 
 class EnterPositionQuantityScaledAction(Action):
@@ -114,13 +131,13 @@ class EnterPositionQuantityScaledAction(Action):
                                     underlier notional
         """
         super().__init__(name)
-        self._priceables = make_list(priceables)
+        self._priceables = []
         self._trade_duration = trade_duration
-        for i, p in enumerate(self._priceables):
+        for i, p in enumerate(make_list(priceables)):
             if p.name is None:
-                p.name = '{}_Priceable{}'.format(self._name, i)
+                self._priceables.append(p.clone(name=f'{self._name}_Priceable{i}'))
             else:
-                p.name = '{}_{}'.format(self._name, p.name)
+                self._priceables.append(p.clone(name=f'{self._name}_{p.name}'))
         self._trade_quantity = trade_quantity
         self._trade_quantity_type = trade_quantity_type
 
@@ -167,7 +184,9 @@ class ExitTradeAction(Action):
 
 class HedgeAction(Action):
     def __init__(self, risk, priceables: Priceable = None, trade_duration: str = None, name: str = None,
-                 csa_term: str = None, scaling_parameter: str = 'notional_amount'):
+                 csa_term: str = None, scaling_parameter: str = 'notional_amount',
+                 transaction_cost: TransactionModel = ConstantTransactionModel(0),
+                 risk_transformation: Transformer = None):
         super().__init__(name)
         self._calc_type = CalcType.semi_path_dependent
         self._priceable = priceables
@@ -175,11 +194,22 @@ class HedgeAction(Action):
         self._trade_duration = trade_duration
         self._csa_term = csa_term
         self._scaling_parameter = scaling_parameter
-        if priceables is not None:
-            if self._priceable.name is None:
-                self._priceable.name = '{}_Priceable{}'.format(self._name, 0)
-            else:
-                self._priceable.name = '{}_{}'.format(self._name, self._priceable.name)
+        self._transaction_cost = transaction_cost
+        self._risk_transformation = risk_transformation
+        if isinstance(priceables, Portfolio):
+            trades = []
+            for i, priceable in enumerate(priceables):
+                if priceable.name is None:
+                    trades.append(priceable.clone(name=f'{self._name}_Priceable{i}'))
+                else:
+                    trades.append(priceable.clone(name=f'{self._name}_{priceable.name}'))
+            self._priceable = Portfolio(trades)
+        else:
+            if priceables is not None:
+                if priceables.name is None:
+                    self._priceable = priceables.clone(name=f'{self._name}_Priceable0')
+                else:
+                    self._priceable = priceables.clone(name=f'{self._name}_{priceables.name}')
 
     @property
     def trade_duration(self):
@@ -200,3 +230,48 @@ class HedgeAction(Action):
     @property
     def scaling_parameter(self):
         return self._scaling_parameter
+
+    @property
+    def transaction_cost(self):
+        return self._transaction_cost
+
+    @property
+    def risk_transformation(self):
+        return self._risk_transformation
+
+
+class RebalanceAction(Action):
+    def __init__(self, priceable: Priceable, size_parameter, method,
+                 transaction_cost: TransactionModel = ConstantTransactionModel(0)):
+        super().__init__()
+        self._calc_type = CalcType.path_dependent
+        self._size_parameter = size_parameter
+        self._method = method
+        self._transaction_cost = transaction_cost
+        if priceable.unresolved is None:
+            raise ValueError("Please specify a resolved priceable to rebalance.")
+        if priceable is not None:
+            if priceable.name is None:
+                self._priceable = priceable.clone(name=f'{self._name}_Priceable0')
+            else:
+                self._priceable = priceable.clone(name=f'{self._name}_{priceable.name}')
+
+    @property
+    def priceable(self):
+        return self._priceable
+
+    @property
+    def size_parameter(self):
+        return self._size_parameter
+
+    @property
+    def method(self):
+        return self._method
+
+    @property
+    def args(self):
+        return self._args
+
+    @property
+    def transaction_cost(self):
+        return self._transaction_cost
