@@ -18,7 +18,7 @@ from abc import ABC
 from collections import defaultdict
 from copy import deepcopy
 from queue import Queue as FifoQueue
-from typing import Iterable, TypeVar
+from typing import Iterable, TypeVar, Optional
 
 import numpy as np
 import pandas as pd
@@ -29,6 +29,7 @@ from gs_quant.backtests.core import ValuationMethod
 from gs_quant.backtests.data_handler import DataHandler
 from gs_quant.backtests.event import FillEvent
 from gs_quant.backtests.order import OrderBase, OrderCost
+from gs_quant.risk.transform import Transformer
 
 
 class BaseBacktest(ABC):
@@ -42,8 +43,9 @@ class BackTest(BaseBacktest):
     def __init__(self, strategy, states, risks):
         self._portfolio_dict = defaultdict(Portfolio)  # portfolio by state
         self._cash_dict = {}  # cash by state
-        self._scaling_portfolios = defaultdict(list)  # list of ScalingPortfolio
+        self._hedges = defaultdict(list)  # list of Hedge by date
         self._cash_payments = defaultdict(list)  # list of cash payments (entry, unwind)
+        self._transaction_costs = defaultdict(int)  # list of transaction costs by date
         self._strategy = deepcopy(strategy)  # the strategy definition
         self._states = states  # list of states
         self._results = defaultdict(list)
@@ -63,14 +65,6 @@ class BackTest(BaseBacktest):
     def portfolio_dict(self, portfolio_dict):
         self._portfolio_dict = portfolio_dict
 
-    @property
-    def scaling_portfolios(self):
-        return self._scaling_portfolios
-
-    @scaling_portfolios.setter
-    def scaling_portfolios(self, scaling_portfolios):
-        self._scaling_portfolios = scaling_portfolios
-
     @property
     def cash_payments(self):
         return self._cash_payments
@@ -79,6 +73,18 @@ class BackTest(BaseBacktest):
     def cash_payments(self, cash_payments):
         self._cash_payments = cash_payments
 
+    @property
+    def transaction_costs(self):
+        return self._transaction_costs
+
+    @property
+    def hedges(self):
+        return self._hedges
+
+    @hedges.setter
+    def hedges(self, hedges):
+        self._hedges = hedges
+
     @property
     def states(self):
         return self._states
@@ -136,7 +142,10 @@ class BackTest(BaseBacktest):
             raise RuntimeError('Cannot aggregate cash in multiple currencies')
         cash = pd.concat([pd.Series(cash_dict, name='Cumulative Cash')
                           for name, cash_dict in cash_summary.items()], axis=1, sort=True)
-        return pd.concat([summary, cash], axis=1, sort=True).fillna(0)
+        transaction_costs = pd.Series(self.transaction_costs, name='Transaction Costs')
+        df = pd.concat([summary, cash, transaction_costs], axis=1, sort=True).fillna(0)
+        df['Total'] = df.sum(numeric_only=True, axis=1)
+        return df[:self.states[-1]]
 
     def trade_ledger(self):
         # this is a ledger of each instrument when it was entered and when it was closed out.  The cash associated
@@ -214,12 +223,14 @@ class BackTest(BaseBacktest):
 
 
 class ScalingPortfolio:
-    def __init__(self, trade, dates, risk, csa_term=None, scaling_parameter='notional_amount'):
+    def __init__(self, trade, dates, risk, csa_term=None, scaling_parameter='notional_amount',
+                 risk_transformation: Transformer = None):
         self.trade = trade
         self.dates = dates
         self.risk = risk
         self.csa_term = csa_term
         self.scaling_parameter = scaling_parameter
+        self.risk_transformation = risk_transformation
         self.results = None
 
 
@@ -238,6 +249,29 @@ class CashPayment:
         return df
 
 
+class Hedge:
+    def __init__(self,
+                 scaling_portfolio: ScalingPortfolio,
+                 entry_payment: CashPayment,
+                 exit_payment: Optional[CashPayment]):
+        self.scaling_portfolio = scaling_portfolio
+        self.entry_payment = entry_payment
+        self.exit_payment = exit_payment
+
+
+class TransactionModel:
+    def get_cost(self, state, backtest, info) -> float:
+        pass
+
+
+class ConstantTransactionModel(TransactionModel):
+    def __init__(self, cost):
+        self._cost = cost
+
+    def get_cost(self, state, backtest, info) -> float:
+        return self._cost
+
+
 class PredefinedAssetBacktest(BaseBacktest):
     """
     :param data_handler: holds all the data required to run the backtest
@@ -314,10 +348,10 @@ class PredefinedAssetBacktest(BaseBacktest):
                     status = 'open'
                 start_dt, open_value = open_order.execution_end_time(), open_order.executed_price
                 long_or_short = np.sign(open_order.quantity)
-                trade_df.append((inst, start_dt, end_dt, open_value, end_value, long_or_short, status,
+                trade_df.append((inst, start_dt, end_dt, open_value, end_value, status,
                                  (end_value - open_value) * long_or_short if status == 'closed' else None))
         return pd.DataFrame(trade_df, columns=['Instrument', 'Open', 'Close', 'Open Value', 'Close Value',
-                                               'Long Short', 'Status', 'Trade PnL'])
+                                               'Status', 'Trade PnL'])
 
     def mark_to_market(self, state: dt.datetime, valuation_method: ValuationMethod):
         epsilon = 1e-12
