@@ -21,6 +21,7 @@ from copy import deepcopy
 from typing import Iterable, Optional, Tuple, Union
 
 from dataclasses_json import global_config
+
 from gs_quant.api.gs.parser import GsParserApi
 from gs_quant.api.gs.risk import GsRiskApi
 from gs_quant.base import get_enum_value, InstrumentBase, Priceable, Scenario
@@ -29,7 +30,7 @@ from gs_quant.markets import HistoricalPricingContext, MarketDataCoordinate, Pri
 from gs_quant.priceable import PriceableImpl
 from gs_quant.risk import FloatWithInfo, DataFrameWithInfo, SeriesWithInfo, ResolvedInstrumentValues, \
     DEPRECATED_MEASURES
-from gs_quant.risk.results import ErrorValue, MultipleRiskMeasureFuture, PricingFuture
+from gs_quant.risk.results import ErrorValue, MultipleRiskMeasureFuture, PricingFuture, MultipleScenarioFuture
 from gs_quant.target.common import MultiScenario
 
 _logger = logging.getLogger(__name__)
@@ -143,10 +144,18 @@ class Instrument(PriceableImpl, InstrumentBase):
 
         usd_delta_f and eur_delta_f are futures, usd_delta and eur_delta are dataframes
         """
+
+        def get_inst_futures(curr_measure):
+            return MultipleScenarioFuture(self, multi_scenario.scenarios,
+                                          (curr_measure.pricing_context.calc(self, curr_measure),)) \
+                if multi_scenario else curr_measure.pricing_context.calc(self, curr_measure)
+
         single_measure = isinstance(risk_measure, RiskMeasure)
+        multi_scenario = next((i for i in Scenario.path if isinstance(i, MultiScenario)), None)
+
         with self._pricing_context:
-            future = risk_measure.pricing_context.calc(self, risk_measure) if single_measure else \
-                MultipleRiskMeasureFuture(self, {r: r.pricing_context.calc(self, r) for r in risk_measure})
+            future = get_inst_futures(risk_measure) if single_measure else \
+                MultipleRiskMeasureFuture(self, {r: get_inst_futures(r) for r in risk_measure})
 
         # Warn on use of deprecated measures
         def warning_on_one_line(msg, category, _filename, _lineno, _file=None, _line=None):
@@ -183,9 +192,10 @@ class Instrument(PriceableImpl, InstrumentBase):
         instrument = cls if hasattr(cls, 'asset_class') else None
         if instrument is None:
             builder_type = values.get('$type') or values.get('builder', values.get('defn', {})).get('$type')
+            values_used = values.get('builder', values.get('defn', values))
             if builder_type:
                 from gs_quant_internal.base import decode_quill_value
-                return decode_quill_value(values)
+                return decode_quill_value(values_used)
 
             asset_class_field = next((f for f in ('asset_class', 'assetClass') if f in values), None)
             if not asset_class_field:
@@ -328,5 +338,9 @@ def encode_instruments(instruments: Optional[Iterable[Instrument]]) -> Optional[
 
 
 global_config.decoders[Instrument] = Instrument.from_dict
+global_config.decoders[InstrumentBase] = Instrument.from_dict
 global_config.encoders[Instrument] = encode_instrument
 global_config.encoders[Priceable] = encode_instrument
+global_config.encoders[Optional[Priceable]] = encode_instrument
+global_config.encoders[Optional[Instrument]] = encode_instrument
+global_config.encoders[Optional[InstrumentBase]] = encode_instrument
