@@ -15,6 +15,7 @@ under the License.
 """
 import datetime as dt
 import logging
+import re
 from dataclasses import dataclass
 from itertools import chain
 from typing import Iterable, Optional, Tuple, Union
@@ -304,11 +305,16 @@ class Portfolio(PriceableImpl):
         if self.portfolios:
             raise ValueError('Cannot save portfolios with nested portfolios')
 
+        pricing_context = self._pricing_context
+        with pricing_context:
+            pricing_date = PricingContext.current.pricing_date
+            market = PricingContext.current.market
+
         request = RiskRequest(
             tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in self.instruments),
             (ResolvedInstrumentValues,),
-            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=self._pricing_context.pricing_date,
-                                                                        market=self._pricing_context.market),)
+            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=pricing_date,
+                                                                        market=market),)
         )
 
         if self.__quote_id:
@@ -326,11 +332,16 @@ class Portfolio(PriceableImpl):
         if self.portfolios:
             raise ValueError('Cannot save portfolios with nested portfolios')
 
+        pricing_context = self._pricing_context
+        with pricing_context:
+            pricing_date = PricingContext.current.pricing_date
+            market = PricingContext.current.market
+
         request = RiskRequest(
             tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in self.instruments),
             (ResolvedInstrumentValues,),
-            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=self._pricing_context.pricing_date,
-                                                                        market=self._pricing_context.market),)
+            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=pricing_date,
+                                                                        market=market),)
         )
         status = GsPortfolioApi.save_to_shadowbook(request, name)
         print(f'Save to shadowbook status - {status}')
@@ -368,6 +379,10 @@ class Portfolio(PriceableImpl):
             mappings: Optional[dict] = None
     ):
         data = pd.read_csv(csv_file, skip_blank_lines=True).replace({np.nan: None})
+        reg = re.compile(r'\.[0-9]')
+        dupelist = [re.sub(reg, '', word) for word in data.columns if reg.search(word)]
+        if len(dupelist):
+            raise ValueError(f'Duplicate column values {dupelist}')
         return cls.from_frame(data, mappings)
 
     def scale(self, scaling: int, in_place: bool = True):
@@ -510,7 +525,6 @@ class Portfolio(PriceableImpl):
         >>>
         >>> portfolio = Portfolio(...)
         >>> market = portfolio.market()
-
         """
         pricing_context = self._pricing_context
         instruments = self._get_instruments(self.__position_context.position_date, False, False)
