@@ -173,7 +173,7 @@ class FloatWithInfo(ScalarWithInfo, float):
     def __new__(cls,
                 risk_key: RiskKey,
                 value: Union[float, str],
-                unit: Optional[str] = None,
+                unit: dict = None,
                 error: Optional[str] = None,
                 request_id: Optional[str] = None):
         return float.__new__(cls, value)
@@ -258,6 +258,14 @@ class SeriesWithInfo(pd.Series, ResultInfo):
     def raw_value(self) -> pd.Series:
         return pd.Series(self)
 
+    @staticmethod
+    def compose(components: Iterable):
+        dates, values, errors, risk_key, unit = ResultInfo.composition_info(components)
+        return SeriesWithInfo(pd.Series(index=pd.DatetimeIndex(dates).date, data=values),
+                              risk_key=risk_key,
+                              unit=unit,
+                              error=errors)
+
     def _to_records(self, extra_dict, display_options: DisplayOptions = None):
         df = pd.DataFrame(self).reset_index()
         df.columns = ['dates', 'value']
@@ -265,6 +273,11 @@ class SeriesWithInfo(pd.Series, ResultInfo):
         records = [dict(item, **{**extra_dict}) for item in records]
         return records
 
+    def __mul__(self, other):
+        new_result = pd.Series.__mul__(self, other)
+        ResultInfo.__init__(new_result, risk_key=self.risk_key, unit=self.unit, error=self.error, request_id=self.request_id)
+        return new_result
+
 
 class DataFrameWithInfo(pd.DataFrame, ResultInfo):
     _internal_names = pd.DataFrame._internal_names + \
@@ -349,7 +362,9 @@ class MQVSValidatorDefn:
     validatorType: str
     targets: Tuple[MQVSValidationTarget]
     args: Dict[str, str]
-
+    groupId: Optional[str] = None
+    groupIndex: Optional[int] = None
+    groupMethod: Optional[str] = None
 
 class MQVSValidatorDefnsWithInfo(ResultInfo):
     validators: Tuple[MQVSValidatorDefn]
