@@ -19,13 +19,12 @@ from typing import Iterable, Optional, Union
 
 from gs_quant.base import InstrumentBase, RiskKey
 from gs_quant.risk.measures import PnlExplain
-from gs_quant.target.measures import EqDelta, EqGamma, EqVega
 
 from .core import DataFrameWithInfo, ErrorValue, UnsupportedValue, FloatWithInfo, SeriesWithInfo, StringWithInfo, \
     sort_values, MQVSValidatorDefnsWithInfo, MQVSValidatorDefn
 
 _logger = logging.getLogger(__name__)
-__scalar_risk_measures = (EqDelta, EqGamma, EqVega)
+__scalar_risk_measures = ('EqDelta', 'EqGamma', 'EqVega')
 
 
 def __dataframe_handler(result: Iterable, mappings: tuple, risk_key: RiskKey, request_id: Optional[str] = None) \
@@ -71,6 +70,7 @@ def __dataframe_handler_unsorted(result: Iterable, mappings: tuple, date_cols: t
 def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None) \
         -> DataFrameWithInfo:
     mappings = (
+        ('currency', 'currency'),
         ('payment_date', 'payDate'),
         ('set_date', 'setDate'),
         ('accrual_start_date', 'accStart'),
@@ -187,7 +187,7 @@ def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
                         request_id: Optional[str] = None) -> DataFrameWithInfo:
     assets = result['asset']
     # Handle equity risk measures which are really scalars
-    if len(assets) == 1 and risk_key.risk_measure in __scalar_risk_measures:
+    if len(assets) == 1 and risk_key.risk_measure.name in __scalar_risk_measures:
         return FloatWithInfo(risk_key, assets[0], request_id=request_id)
 
     for points, value in zip(result['points'], assets):
@@ -328,14 +328,6 @@ def unsupported_handler(_result: dict, risk_key: RiskKey, _instrument: Instrumen
     return UnsupportedValue(risk_key, request_id=request_id)
 
 
-def extract_val_from_dataframe_with_info(df: DataFrameWithInfo, value_key: str = 'value'):
-    result = []
-    for val in df[value_key]:
-        if isinstance(val, float):
-            result.append(FloatWithInfo(value=val, unit=df.unit, risk_key=df.risk_key, request_id=df.request_id))
-    return result
-
-
 result_handlers = {
     'Error': error_handler,
     'IRPCashflowTable': cashflows_handler,
