@@ -206,7 +206,8 @@ class Basket:
             # If duplicate assets exist, asset_dict will contain a entry for the one with the higher rank (relevant)
             assets_dict = {entry['bbid']: entry['id'] for entry in assets}
             if len(assets_dict) != len(set(self.bbids)):
-                raise MqValueError('Unable to find all stocks')
+                not_found = set(assets_dict).symmetric_difference(self.bbids)
+                raise MqValueError(f'Unable to find stocks: {", ".join(not_found)}')
             self._marquee_ids = [assets_dict[bbid] for bbid in self.bbids]
 
         return self._marquee_ids
@@ -401,6 +402,18 @@ class Basket:
     def average_forward_vol(self, tenor: str, forward_start_date: str, strike_reference: VolReference,
                             relative_strike: Real, *, real_time: bool = False, request_id: Optional[str] = None,
                             source: Optional[str] = None) -> pd.Series:
+        """
+        Weighted average forward volatility.
+
+        :param tenor: relative date representation of expiration date e.g. 1m
+        :param forward_start_date: forward start date e.g. 2m, 1y
+        :param strike_reference: reference for strike level
+        :param relative_strike: strike relative to reference
+        :param real_time: whether to retrieve intraday data instead of EOD
+        :param request_id: service request id, if any
+        :param source: name of function caller
+        :return: average forward volatility
+        """
         if real_time:
             raise NotImplementedError('real-time basket forward vol not implemented')
 
