@@ -47,7 +47,8 @@ except ImportError:
                 if pd.Timestamp(index[j]) > index[i] - offset:
                     start = j
                     break
-            results[i] = np.std(values[start:i + 1], ddof=1)
+            section = values[start:i + 1]
+            results[i] = np.std(section[section == section], ddof=1)
         return pd.Series(results, index=index, dtype=np.double)
 
 
@@ -126,7 +127,8 @@ def min_(x: Union[pd.Series, List[pd.Series]], w: Union[Window, int, str] = Wind
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].min() for idx in x.index]
+        values = rolling_offset(x, w.w, np.nanmin, 'min') if isinstance(x, pd.Series) else [
+            x.loc[(x.index > idx - w.w) & (x.index <= idx)].min() for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).min(), w)
@@ -192,7 +194,8 @@ def max_(x: Union[pd.Series, List[pd.Series]], w: Union[Window, int, str] = Wind
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].max() for idx in x.index]
+        values = rolling_offset(x, w.w, np.nanmax, 'max') if isinstance(x, pd.Series) else [
+            x.loc[(x.index > idx - w.w) & (x.index <= idx)].max() for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).max(), w)
@@ -287,9 +290,15 @@ def mean(x: Union[pd.Series, List[pd.Series]], w: Union[Window, int, str] = Wind
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [np.nanmean(x.loc[(x.index > idx - w.w) & (x.index <= idx)]) for idx in x.index]
+        if isinstance(x, pd.Series):
+            values = rolling_offset(x, w.w, np.nanmean, 'mean')
+        else:
+            values = [np.nanmean(x.loc[(x.index > idx - w.w) & (x.index <= idx)]) for idx in x.index]
     else:
-        values = [np.nanmean(x.iloc[max(idx - w.w + 1, 0): idx + 1]) for idx in range(0, len(x))]
+        if isinstance(x, pd.Series):
+            values = x.rolling(w.w, 0).mean()  # faster than slicing in Python
+        else:
+            values = [np.nanmean(x.iloc[max(idx - w.w + 1, 0): idx + 1]) for idx in range(0, len(x))]
     return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
 
 
@@ -331,7 +340,8 @@ def median(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) -> pd.Ser
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].median() for idx in x.index]
+        values = rolling_offset(x, w.w, np.nanmedian, 'median') if isinstance(x, pd.Series) else [
+            x.loc[(x.index > idx - w.w) & (x.index <= idx)].median() for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).median(), w)
@@ -370,7 +380,8 @@ def mode(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) -> pd.Serie
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [stats.mode(x.loc[(x.index > idx - w.w) & (x.index <= idx)]).mode[0] for idx in x.index]
+        values = rolling_apply(x, w.w, lambda a: stats.mode(a).mode[0]) if isinstance(x, pd.Series) else [
+            stats.mode(x.loc[(x.index > idx - w.w) & (x.index <= idx)]).mode[0] for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).apply(lambda y: stats.mode(y).mode, raw=True), w)
@@ -423,8 +434,9 @@ def sum_(x: Union[pd.Series, List[pd.Series]], w: Union[Window, int, str] = Wind
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].sum() for idx in x.index]
-        return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
+        assert isinstance(x, pd.Series), 'expected a series'
+        values = rolling_offset(x, w.w, np.nansum, 'sum')
+        return apply_ramp(values, w)
     else:
         return apply_ramp(x.rolling(w.w, 0).sum(), w)
 
@@ -463,7 +475,8 @@ def product(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) -> pd.Se
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].agg(pd.Series.prod) for idx in x.index]
+        values = rolling_offset(x, w.w, np.nanprod, 'prod') if isinstance(x, pd.Series) else [
+            x.loc[(x.index > idx - w.w) & (x.index <= idx)].prod() for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).agg(pd.Series.prod), w)
@@ -602,7 +615,8 @@ def var(x: pd.Series, w: Union[Window, int, str] = Window(None, 0)) -> pd.Series
     w = normalize_window(x, w)
     assert x.index.is_monotonic_increasing, "series index is monotonic increasing"
     if isinstance(w.w, pd.DateOffset):
-        values = [x.loc[(x.index > idx - w.w) & (x.index <= idx)].var() for idx in x.index]
+        values = rolling_offset(x, w.w, lambda a: np.nanvar(a, ddof=1), 'var') if isinstance(x, pd.Series) else [
+            x.loc[(x.index > idx - w.w) & (x.index <= idx)].var() for idx in x.index]
         return apply_ramp(pd.Series(values, index=x.index, dtype=np.dtype(float)), w)
     else:
         return apply_ramp(x.rolling(w.w, 0).var(), w)
@@ -1186,7 +1200,9 @@ class SIRModel:
         self.beta_fixed = not (self.fit or (self.beta_init is None))
         self.gamma_fixed = not (self.fit or (self.gamma_init is None))
 
-        data = np.array([self.s, self.i, self.r]).T
+        lens = [len(x) for x in (self.s, self.i, self.r)]
+        dtype = float if max(lens) == min(lens) else object
+        data = np.array([self.s, self.i, self.r], dtype=dtype).T
 
         beta_init = self.beta_init if self.beta_init is not None else 0.9
         gamma_init = self.gamma_init if self.gamma_init is not None else 0.01
@@ -1372,7 +1388,9 @@ class SEIRModel(SIRModel):
         self.gamma_fixed = not (self.fit or (self.gamma is None))
         self.sigma_fixed = not (self.fit or (self.sigma is None))
 
-        data = np.array([self.s, self.e, self.i, self.r]).T
+        lens = [len(x) for x in (self.s, self.e, self.i, self.r)]
+        dtype = float if max(lens) == min(lens) else object
+        data = np.array([self.s, self.e, self.i, self.r], dtype=dtype).T
 
         beta_init = self.beta_init if self.beta_init is not None else 0.9
         gamma_init = self.gamma_init if self.gamma_init is not None else 0.01
